//=========================================================================
//
//	FILE:				CP_Graphics_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_Grapics demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 5 $
//						Latest Checkout:  $Date: 2005-07-17 20:24:02 -0700 (Sun, 17 Jul 2005) $
//
//=========================================================================

	// Precompile header support
#include "CP_Precomp.h"

	// CP_Graphics;
#include "CP_Graphics_App.h"
#include "CP_DemoImageView.h"
#include "CP_DemoPathsView.h"
#include "CP_DemoShapesView.h"

	// CPLAT_Framework
#include "CP_Application.tmpl.h"
#include "CP_GetFileDialog.h"
#include "CP_Window.h"
#include "CP_WindowManager.h"

	// local file defines
#define kCP_Graphics_ShapesCommand					1000
#define kCP_Graphics_PathsCommand					1001
#define kCP_Graphics_ImagesCommand					1002

#if TARGET_CC_METROWERKS
#pragma mark === Construction / Destruction ==
#endif

//=========================================================================
//	FUNCTION:	CP_Graphics_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_Graphics_Application::CP_Graphics_Application()
{
	RegisterCommand( kCP_Graphics_ShapesCommand,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Graphics_Application::HandleShapes) );

	RegisterCommand( kCP_Graphics_PathsCommand,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Graphics_Application::HandlePaths) );

	RegisterCommand( kCP_Graphics_ImagesCommand,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Graphics_Application::HandleImages) );
}

//=========================================================================
//	FUNCTION:	~CP_Graphics_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_Graphics_Application::~CP_Graphics_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark === AboutBox ===
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String CP_Graphics_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to demonstrate the CP_Graphics class.";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark === Main Window ===
#endif

//=========================================================================
//	FUNCTION:	HandleOpenApplication
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the application is starting up. We take this opportunity to
*	create our initial window and views. In this demo, we will open the buttons
*	window.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Graphics_Application::HandleOpenApplication()
{
	CPLAT::OSStatus			status = CP_noErr;
	CPLAT::CP_CommandNo		command = kCP_Graphics_ShapesCommand;
	
	HandleShapes( status, command );
}

#if TARGET_CC_METROWERKS
#pragma mark === Images ==
#endif

//=========================================================================
//	FUNCTION:	AskForImageFile
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Present the user with a GetFileDialog to allow them to select the image
*	file to be displayed.
*	
*	@exception	none
*
*	@return		CP_FileSystemSpec	The file system spec of the image file to
*									be used.
*/
CPLAT::CP_FileSystemSpec CP_Graphics_Application::AskForImageFile()
{
	CPLAT::CP_FileSystemSpec		returnSpec;
	
	try
	{
		CPLAT::CP_GetFileDialog		getFileDialog;
		
		getFileDialog.SetModality( CPLAT::kCP_E_WindowModalityAppModal, NULL );

		getFileDialog.Run();
		
		CPLAT::CP_FileSystemSpec_Array		selectedFiles = getFileDialog.GetSelectedFilesList();

		if( selectedFiles.size() > 0 )
			returnSpec = selectedFiles.at( 0 );
	}
	catch(...)
	{
	}
	
	return( returnSpec );
}

#if TARGET_CC_METROWERKS
#pragma mark === Tests ==
#endif

//=========================================================================
//	FUNCTION:	HandleShapes
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Handle the show shapes command to display a window that displays various
*	shapes available with CP_Graphics.
*
*	@param		inOutStatus			Not used.
*	@param		inCommandNo			Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Graphics_Application::HandleShapes( CPLAT::OSStatus& /*inOutStatus*/,
	CPLAT::CP_CommandNo& /*inCommandNo*/ )
{
	try
	{
		CPLAT::CP_Window				*window = NULL;
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 400, 500 );
		CPLAT::CP_String				windowTitle( "CP_Graphics Shapes" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		
		window = CP_new CPLAT::CP_Window();
		window->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( window );

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 400, 500 );
		CP_DemoShapesView				*shapesView = NULL;
		
		shapesView = CP_new CP_DemoShapesView( window, viewLocation, viewSize );

		CPLAT::CP_WindowManager::Instance()->Reposition( window, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		window->Show();
	}
	catch(...)
	{
	}
}

//=========================================================================
//	FUNCTION:	HandlePaths
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Handle the show paths command to display a window that displays various
*	paths available with CP_Graphics.
*
*	@param		inOutStatus			Not used.
*	@param		inCommandNo			Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Graphics_Application::HandlePaths( CPLAT::OSStatus& /*inOutStatus*/,
	CPLAT::CP_CommandNo& /*inCommandNo*/ )
{
	try
	{
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 400, 500 );
		CPLAT::CP_String				windowTitle( "CP_Graphics Paths" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		CPLAT::CP_Window				*window = NULL;
		
		window = CP_new CPLAT::CP_Window();
		window->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( window );

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 400, 500 );
		CP_DemoPathsView				*pathsView = NULL;
		
		pathsView = CP_new CP_DemoPathsView( window, viewLocation, viewSize );

		CPLAT::CP_WindowManager::Instance()->Reposition( window, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		window->Show();
	}
	catch(...)
	{
	}
}

//=========================================================================
//	FUNCTION:	HandleImages
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Handle the show images command to display a window that displays various
*	images using CP_Graphics.
*
*	@param		inOutStatus			Not used.
*	@param		inCommandNo			Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Graphics_Application::HandleImages( CPLAT::OSStatus& /*inOutStatus*/,
	CPLAT::CP_CommandNo& /*inCommandNo*/ )
{
	try
	{
		CPLAT::CP_FileSystemSpec		imageFileSpec = AskForImageFile();
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 400, 500 );
		CPLAT::CP_String				windowTitle( "CP_Graphics Images" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		CPLAT::CP_Window				*window = NULL;
		
		window = CP_new CPLAT::CP_Window();
		window->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( window );

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 400, 500 );
		CP_DemoImageView				*imagesView = NULL;
		
		imagesView = CP_new CP_DemoImageView( window, viewLocation, viewSize, false );
		imagesView->SetSpec( imageFileSpec );
		
		CPLAT::CP_WindowManager::Instance()->Reposition( window, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		window->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
