//=========================================================================
//
//	FILE:				CP_Tables_App.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the CP_Tables demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 5 $
//						Latest Checkout:  $Date: 2005-08-30 20:33:42 -0700 (Tue, 30 Aug 2005) $
//
//=========================================================================

	// CP_Document
#include "CP_FinderLike_TV_DB_Doc.h"
#include "CP_InPlaceEdit_TV_DB_Doc.h"
#include "CP_Simple_TV_DB_Doc.h"
#include "CP_ViewContent_TV_DB_Doc.h"
#include "CP_Tables_App.h"

	// CPLAT_Framework
#include "CP_Application.tmpl.h"
#include "CP_Data_ResourceTypes.h"
#include "CP_DocumentFactoryManager.h"
#include "CP_DocumentPolicy_Multi.h"

	// Commands
const UInt32 kCP_TableDemo_SimpleTVDataBrowser		 				= 1000;
const UInt32 kCP_TableDemo_InPlaceEditTVDataBrowser		 			= 1001;
const UInt32 kCP_TableDemo_ViewContentTVDataBrowser		 			= 1002;
const UInt32 kCP_TableDemo_FinderLikeTVDataBrowser		 			= 1003;

	// DocumentTypes
const UInt32 kCP_TableDemo_SimpleTVDataBrowser_DocType		 		= CP_FOUR_CHAR_CODE('STVD');
const UInt32 kCP_TableDemo_InPlaceEditTVDataBrowser_DocType			= CP_FOUR_CHAR_CODE('INED');
const UInt32 kCP_TableDemo_ViewContentTVDataBrowser_DocType			= CP_FOUR_CHAR_CODE('VIEC');
const UInt32 kCP_TableDemo_FinderLikeTVDataBrowser_DocType			= CP_FOUR_CHAR_CODE('FIND');

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	CP_Tables_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_Tables_Application::CP_Tables_Application()
{
	GetDocumentPolicy().SetDefaultDocumentType( kCP_TableDemo_FinderLikeTVDataBrowser_DocType );
	
	CP_RegisterCommand( kCP_TableDemo_SimpleTVDataBrowser,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Tables_Application::HandleCommand) );
	CP_RegisterCommand( kCP_TableDemo_InPlaceEditTVDataBrowser,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Tables_Application::HandleCommand) );
	CP_RegisterCommand( kCP_TableDemo_ViewContentTVDataBrowser,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Tables_Application::HandleCommand) );
	CP_RegisterCommand( kCP_TableDemo_FinderLikeTVDataBrowser,
		CPLAT::CP_Command::CP_E_CH_AlwaysEnable)->connect( CPLAT::CP_SigSlot::slot(this, &CP_Tables_Application::HandleCommand) );
}

//=========================================================================
//	FUNCTION:	~CP_Tables_Application
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_Tables_Application::~CP_Tables_Application() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === AboutBox ===
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	GetAboutBoxDescription
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Return the string that describes the purpose of the application in the
*	AboutBox.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
CPLAT::CP_String CP_Tables_Application::GetAboutBoxDescription() const
{
	CPLAT::CP_String		returnDescription;
	
	returnDescription = "A simple CPLAT application to demonstrate table handling.";
	
	return( returnDescription );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Commands ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleCommand
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Handles the passed in command.
*
*	@param		inOutStatus			Not used.
*	@param		inCommandNo			The command being handled. This command number
*									determines the window to be displayed.
*	
*	@exception	none
*
*	@return		CP_String const		The description, displayed in the about box.
*/
void CP_Tables_Application::HandleCommand( CPLAT::OSStatus& inOutStatus,
	CPLAT::CP_CommandNo& inCommandNo )
{
	CPLAT::CP_Document_Base		*document = NULL;

	switch( inCommandNo )
	{
		case kCP_TableDemo_SimpleTVDataBrowser:
			{
				document = CPLAT::CP_DocumentFactoryManager::Instance()->CreateDocument( NULL, kCP_TableDemo_SimpleTVDataBrowser_DocType );
				document->DoPostCreate( CPLAT::CP_Document_Base::CP_E_Doc_Create_CreateUIOnNew );
			}
			break;
			
		case kCP_TableDemo_InPlaceEditTVDataBrowser:
			{
				document = CPLAT::CP_DocumentFactoryManager::Instance()->CreateDocument( NULL, kCP_TableDemo_InPlaceEditTVDataBrowser_DocType );
				document->DoPostCreate( CPLAT::CP_Document_Base::CP_E_Doc_Create_CreateUIOnNew );
			}
			break;

		case kCP_TableDemo_ViewContentTVDataBrowser:
			{
				document = CPLAT::CP_DocumentFactoryManager::Instance()->CreateDocument( NULL, kCP_TableDemo_ViewContentTVDataBrowser_DocType );
				document->DoPostCreate( CPLAT::CP_Document_Base::CP_E_Doc_Create_CreateUIOnNew );
			}
			break;

		case kCP_TableDemo_FinderLikeTVDataBrowser:
			{
				document = CPLAT::CP_DocumentFactoryManager::Instance()->CreateDocument( NULL, kCP_TableDemo_FinderLikeTVDataBrowser_DocType );
				document->DoPostCreate( CPLAT::CP_Document_Base::CP_E_Doc_Create_CreateUIOnNew );
			}
			break;
	}
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Documents ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	RegisterDocuments
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Register the objects of type CP_Document_Base and their default file type
*	that are used to create a new document when the application requests a new
*	document of a specific type be created. In this demo, we register a document
*	of type 'TEXT'.
*	
*	@exception	none
*
*	@return		void
*/
void CP_Tables_Application::RegisterDocuments()
{
	#if TARGET_OS_MAC
		CPLAT::CP_DocumentRegistration<CP_Simple_TV_DataBrowser_Doc>::CP_DocumentRegistration( 'STVD'/*kCP_TableDemo_SimpleTVDataBrowser_DocType*/ );
		CPLAT::CP_DocumentRegistration<CP_InPlaceEdit_TV_DataBrowser_Doc>::CP_DocumentRegistration( 'INED'/*kCP_TableDemo_InPlaceEditTVDataBrowser_DocType*/ );
		CPLAT::CP_DocumentRegistration<CP_ViewContent_TV_DataBrowser_Doc>::CP_DocumentRegistration( 'VIEC'/*kCP_TableDemo_ViewContentTVDataBrowser_DocType*/ );
		CPLAT::CP_DocumentRegistration<CP_FinderLike_TV_DataBrowser_Doc>::CP_DocumentRegistration( 'FIND'/*kCP_TableDemo_FinderLikeTVDataBrowser_DocType*/ );
	#else
		CPLAT::CP_DocumentRegistration<CP_Simple_TV_DataBrowser_Doc>::CP_DocumentRegistration( kCP_TableDemo_SimpleTVDataBrowser_DocType );
		CPLAT::CP_DocumentRegistration<CP_InPlaceEdit_TV_DataBrowser_Doc>::CP_DocumentRegistration( kCP_TableDemo_InPlaceEditTVDataBrowser_DocType );
		CPLAT::CP_DocumentRegistration<CP_ViewContent_TV_DataBrowser_Doc>::CP_DocumentRegistration( kCP_TableDemo_ViewContentTVDataBrowser_DocType );
		CPLAT::CP_DocumentRegistration<CP_FinderLike_TV_DataBrowser_Doc>::CP_DocumentRegistration( kCP_TableDemo_FinderLikeTVDataBrowser_DocType );
	#endif
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
