//=========================================================================
//
//	FILE:				Undo_Doc.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_Undo demo document class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 5 $
//						Latest Checkout:  $Date: 2005-08-30 20:34:20 -0700 (Tue, 30 Aug 2005) $
//
//=========================================================================

	// Document
#include "Undo_ContentView.h"
#include "Undo_Doc.h"

	// CPLAT_Framework
#include "CP_Data_ResourceTypes.h"
#include "CP_Debugging.h"
#include "CP_Document.Tmpl.h"
#include "CP_DocumentWindow.h"
#include "CP_Environment.h"
#include "CP_File.h"
#include "CP_New.h"
#include "CP_MenuBarManager.h"
#include "CP_OSStatus.h"
#include "CP_PersistantWritersManager.h"
#include "CP_PrintView.h"
#include "CP_Types.h"
#include "CP_Window.h"
#include "CP_WindowManager.h"

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	Undo_Doc
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*
*	@param		inContainer			The scriptable object that serves as a container
*									for this document. In this case it will be the
*									application object.
*	@param		inDocType			The documents default file type.
*	
*	@exception	none
*/
Undo_Doc::Undo_Doc( CPLAT::CP_ScriptableObject *inContainer, CPLAT::FourCharCode inDocType )
	: inherited( inContainer, inDocType )
{
}

//=========================================================================
//	FUNCTION:	~Undo_Doc
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*
*	@exception	none
*/
Undo_Doc::~Undo_Doc() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Creation ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	DocumentCreator
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Called when some action has requested we create a new document object. This
*	is usually called from the CP_DocumentFactoryManager when it needs to create
*	a new document.
*
*	@param		inContainer			The scriptable object that serves as a container
*									for this document. In this case it will be the
*									application object.
*	@param		inDocumentClass		The documents default file type.
*	
*	@exception	none
*
*	@return		void
*/
CPLAT::CP_Document_Base *Undo_Doc::DocumentCreator( CPLAT::CP_ScriptableObject *inContainer,
	CPLAT::FourCharCode inDocumentClass )
{
	return( CP_new Undo_Doc( inContainer, inDocumentClass ) );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Main Window ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleCreateDocumentUI
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Called when the document wants to create the main user interface for the
*	document. In this demo we create a window, with a CP_TextView in it.
*
*	@param		inPostCreateFlags		Not used.
*	
*	@exception	none
*
*	@return		void
*/
void Undo_Doc::HandleCreateDocumentUI( SInt32 inPostCreateFlags )
{
	try
	{
		CPLAT::CP_DocumentWindow		*mainWindow = NULL;
		CPLAT::CP_Point					windowLocation( 50, 50 );
		CPLAT::CP_Size					windowSize( 400, 400 );
		CPLAT::CP_String				windowTitle( "Undo" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		
		mainWindow = CP_new CPLAT::CP_DocumentWindow();
		mainWindow->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( mainWindow );

		CPLAT::CP_Point				viewLocation( 0, 0 );
		CPLAT::CP_Size				viewSize( 400, 400 );
		Undo_ContentView			*contentView = NULL;
		
		contentView = CP_new Undo_ContentView( mainWindow, viewLocation, viewSize );

			// associate our main window as the documents main window.
		SetMainWindow( mainWindow );
		
		CPLAT::CP_WindowManager::Instance()->Reposition( mainWindow, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		mainWindow->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Persistant Writers ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	CreateWriter
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when the document is being saved. This will create a return a
*	CP_PersistantWriter object that is used to save the actual data.
*
*	@param		inReturnWriter			Location to return the persistant writer in.
*	@param		inOSType				Not used.
*	
*	@exception	none
*
*	@return		void
*/
void Undo_Doc::CreateWriter( CPLAT::CP_PersistantWriter **inReturnWriter,
	CPLAT::FourCharCode /*inOSType*/ )
{
}

//=========================================================================
//	FUNCTION:	GetFileTypeInfo
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	Called when we need to get the file type information for our documents
*	file. In this demo, we supply the creator as the applications creator code,
*	and the files extensio as 'txt' for a text file.
*	
*	@exception	none
*
*	@return		void
*/
void Undo_Doc::GetFileTypeInfo( const CPLAT::CP_FileSystemSpec& /*inFileSpec*/,
	CPLAT::FourCharCode *inOutCreator, CPLAT::FourCharCode *inOutType,
	CPLAT::CP_String *inOutFileExtension )
{
	if( inOutCreator != NULL )
		*inOutCreator = CPLAT::CP_Environment::GetCreator();
	*inOutType = CPLAT::kCP_BinaryDataType;
	*inOutFileExtension = "txt";
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
