//=========================================================================
//
//	FILE:				CP_M_Listener.h
//	
//						Copyright  2003. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Mix-in class to allow objects to listen for messages from
//						CP_M_Broadcasters.
//	
//	HISTORY:			1st Version - November 2003.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Revision: 222 $
//						Latest Checkout:  $Date: 2005-06-28 17:17:59 -0700 (Tue, 28 Jun 2005) $
//
//=========================================================================

#ifndef _H_CP_M_Listener
#define _H_CP_M_Listener
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Message.h"
#include "CP_Types.h"

	// Standard Library
#include <list>

CPLAT_Begin_Namespace_CPLAT

	// Forward declarations
class CP_EXPORT CP_M_Broadcaster;

	// typedefs
#ifndef TARGET_OS_LINUX
	typedef std::list< CP_M_Broadcaster *, std::allocator<CP_M_Broadcaster *> >				CP_Broadcasters;
	typedef std::list< CP_M_Broadcaster *, std::allocator<CP_M_Broadcaster *> >::iterator	CP_Broadcasters_Iterator;
#else
	typedef std::list< CP_M_Broadcaster * >													CP_Broadcasters;
	typedef std::list< CP_M_Broadcaster * >::iterator										CP_Broadcasters_Iterator;
#endif

/*!
*	@class	CP_M_Listener
*	@brief	Mix-in class to allow objects to listen for messages from CP_M_Broadcasters
*/

class CP_EXPORT CP_M_Listener
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
	virtual								~CP_M_Listener();
	//@}
			
	//! @name Broadcasters
	//@{
			void						AddBroadcaster( CP_M_Broadcaster *inBroadcaster );
			void						RemoveBroadcaster( CP_M_Broadcaster *inBroadcaster );
	//@}

	//! @name Listing
	//@{
										/*!
										*	Virtual method that subclasses must override.
										*
										*	@param		inMessage		The message to listen for.
										*	
										*	@exception	none
										*	
										*	@return		void
										*/
	virtual void						ListenForMessage( CP_Message& inMessage ) = 0;

										/*!
										*	Turns off classes from receiving messages.
										*	
										*	@exception	none
										*	
										*	@return		void
										*/
			void						StartListening()							{ fIsListening = true; }

										/*!
										*	Turns on classes to receive messages.
										*	
										*	@exception	none
										*	
										*	@return		void
										*/
			void						StopListening()								{ fIsListening = false; }

										/*!
										*	Returns the flag to indicate if we are currently
										*	listening for messages.
										*	
										*	@exception	none
										*	
										*	@return		bool		Flag to indicate if we are listening for messages.
										*/
			bool						IsListening() const							{ return( fIsListening ); }
	//@}

protected:
	//! @name Constructor / Destructor
	//@{
										CP_M_Listener();
	//@}

private:
	//! @name Constructor / Destructor
	//@{
										CP_M_Listener( const CP_M_Listener& );
	//@}

	//! @name operators
	//@{
	CP_M_Listener&						operator = ( const CP_M_Listener& );
	//@}

	// class data
protected:
	CP_Broadcasters						*fBroadcasters;		/*! List of broadcasters for this listener. */

	bool								fIsListening;		/*! Flag to indicate if we are listening for messages. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_M_Listener

