//=========================================================================
//
//	FILE:				CP_OSTypes.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Template class definitions for various integer types
//						used in CPLAT.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_OSTypes
#define _H_CP_OSTypes
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

//!  CP_IntegerType
/*!
  Template class definitions for various integer types used in CPLAT. 
*/
template <class Tag, typename UnderlyingType, UnderlyingType inDefaultValue = 0>
class CP_EXPORT CP_IntegerType
{
public:
									// Construction / destruction
										CP_IntegerType()
											: fValue(inDefaultValue) 						{}
										CP_IntegerType( UnderlyingType inValue )
											: fValue(inValue)								{}
						
									// Conversion			
										operator UnderlyingType() const						{ return( fValue ); }
										operator UnderlyingType&()							{ return( fValue ); }
	
									// Getters			
			UnderlyingType				Get() const											{ return( fValue ); }

									// Comparison			
			bool						operator == (const CP_IntegerType& inRhs) const { return fValue == inRhs.fValue; }
			bool						operator != (const CP_IntegerType& inRhs) const { return fValue != inRhs.fValue; }
			bool						operator < (const CP_IntegerType& inRhs) const { return fValue < inRhs.fValue; }
			bool						operator <= (const CP_IntegerType& inRhs) const { return fValue <= inRhs.fValue; }
			bool						operator > (const CP_IntegerType& inRhs) const { return fValue > inRhs.fValue; }
			bool						operator >= (const CP_IntegerType& inRhs) const { return fValue >= inRhs.fValue; }
			bool						operator == (UnderlyingType inRhs) const { return fValue == inRhs; }
			bool						operator != (UnderlyingType inRhs) const { return fValue != inRhs; }
			bool						operator < (UnderlyingType inRhs) const { return fValue < inRhs; }
			bool						operator <= (UnderlyingType inRhs) const { return fValue <= inRhs; }
			bool						operator > (UnderlyingType inRhs) const { return fValue > inRhs; }
			bool						operator >= (UnderlyingType inRhs) const { return fValue >= inRhs; }
	
									// Assignment
			CP_IntegerType&				operator = (const CP_IntegerType& inRhs) { fValue = inRhs.fValue; return *this; }
			CP_IntegerType&				operator = (UnderlyingType inRhs) { fValue = inRhs; return *this; }
	
	// class data
protected:
	UnderlyingType						fValue;
};

#if TARGET_OS_MAC
	class FourCharCodeTag {};
	typedef CP_IntegerType< FourCharCodeTag, ::FourCharCode, '\?\?\?\?' >	FourCharCode;

	class OSTypeTag {};
	typedef CP_IntegerType< OSTypeTag, ::OSType, '\?\?\?\?' >				OSType;

	class ResTypeTag {};
	typedef CP_IntegerType< ResTypeTag, ::ResType, '\?\?\?\?' >				ResType;

	class FlavorTypeTag {};
	typedef CP_IntegerType< FlavorTypeTag, ::FlavorType, '\?\?\?\?' >		FlavorType;
#endif

#if TARGET_OS_WIN32 || TARGET_OS_LINUX
	class FourCharCodeTag {};
	typedef CP_IntegerType< FourCharCodeTag, unsigned long, '\?\?\?\?' >	FourCharCode;

	class OSTypeTag {};
	typedef CP_IntegerType< OSTypeTag, unsigned long, '\?\?\?\?' >			OSType;
	   
	class ResTypeTag {};
	typedef CP_IntegerType< ResTypeTag, unsigned long, '\?\?\?\?' >			ResType;

	class FlavorTypeTag {};
	typedef CP_IntegerType< FlavorTypeTag, unsigned long, '\?\?\?\?' >		FlavorType;
#endif

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_OSTypes
