//=========================================================================
//
//	FILE:				CP_Persist_XML_CPEditor.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class that knows how to read the XML file produced
//						by the CPLAT Editor and produce a CP_DataValueList.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Persist_XML_CPEditor
#define _H_CP_Persist_XML_CPEditor
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_M_Persist.h"
#include "CP_NoCopy.h"
#include "CP_ObjectDescriptions.h"
#include "CP_SignalSlotConnections.h"
#include "CP_XMLDocument.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Persist_XML_CPEditor
*	@brief		This class is designed to read the UI data in an xml format used by the CP_Editor.
*
*				The format of the xml data is as follows:
*
*	@begincode
*					<?xml version="1.0" encoding="UTF-8"?>
*					<cplat_description>
*						<ui_description>
*							<widget id="1" class="CPLAT::CP_Window">
*								<CP_Rect name="bounds">32 60 732 567</CP_Rect>
*								<UInt32 name="class">6</UInt32>
*								<UInt32 name="attributes">34078720</UInt32>
*								<CP_String name="text">Simple Hello</CP_String>
*							</widget>
*							<array count="2" name="subviews">
*								<widget id="1" class="CPLAT::CP_TextGroupBox">
*									<CP_Rect name="bounds">20 20 520 320</CP_Rect>
*									<CP_String name="text">Box - at 20,20 size 500,300</CP_String>
*								</widget>
*								<widget id="1" class="CPLAT::CP_PushButton">
*									<CP_Rect name="bounds">557 34 627 54</CP_Rect>
*									<CP_String name="text">Button</CP_String>
*								</widget>
*							</array>
*						</ui_description>
*					</cplat_description>
*	@endcode
*/

class CP_EXPORT CP_Persist_XML_CPEditor : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Persist_XML_CPEditor();
	//! Destructor.
	virtual								~CP_Persist_XML_CPEditor();
	//@}
			
	//! @name Creation
	//@{
	CP_M_Persist						*Create(
												CP_XMLDocument& inXMLDocument,
												CP_View *inSuperview = NULL,
												bool inDocumentWindow = false );
	//@}

protected:
	//! @name DataValue List
	//@{
		CP_DataValueList				CreateDataValueList( CP_XMLDocNode *inContainingViewDocNode );
	//@}

private:
	//! @name Creation
	//@{
		CP_M_Persist					*CreateUISection(
												CP_XMLDocNode *inDocNode,
												CP_View *inSuperview = NULL,
												bool inDocumentWindow = false );
		
		void							CreateSignalSlotSection( CP_XMLDocNode *inDocNode );
		void							HandleSignalSlotConnection( CP_XMLDocNode *inDocNode );

		CP_M_Persist 					*CreateToplevelView(
												CP_XMLDocNode *inDocNode, 
												CP_View *inSuperview = NULL,
												bool inDocumentWindow = false );
		void							CreateSubviewSection(
												CP_XMLDocNode *inDocNode,
												CP_View *inSuperview );
	//@}

	// class data
protected:
	CP_ObjectDescriptions				fObjectDescriptions;		/*! List of object descriptions.*/
	CP_SignalSlotConnections			fSignalConnections;			/*! List of signal / slot connections.*/
		
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Persist_XML_CPEditor

