//=========================================================================
//
//	FILE:				CP_Persistant.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Base class for objects that need to maintain their data
//						in a persistant state such as documents.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Persistant
#define _H_CP_Persistant
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_File.h"
#include "CP_FileSystemSpec.h"
#include "CP_Window.h"

CPLAT_Begin_Namespace_CPLAT

	// foward class declarations
class CP_PersistantWriter;

/*!
*	@class		CP_Persistant
*	@brief		Base class for objects that need to maintain persistant data.
*	
*				This class is used as a base class for objects that need to maintain
*				some data in a persistant state such as documents. You can use with
*				the associated CP_PersistantWriter class to write the data out.
*/
class CP_EXPORT CP_Persistant
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
	virtual								~CP_Persistant();
	//@}
			
	//! @name Dirty
	//@{
	virtual	bool						IsDirty()											{ return( fDirty ); }
	virtual	void						SetDirty( bool inIsDirty )							{ fDirty = inIsDirty; }
	//@}

	//! @name Savinng
	//@{
	virtual	bool						HandleSave(
												const CP_FileSystemSpec& inFileSpec,
												FourCharCode inCreator,
												FourCharCode inType,
												const CP_String& inFileExtension,
												bool inReplaceFile );
	//@}
	
	//! @name Reading / Writing
	//@{
										/*!
										*	Method call by our persistant writer to write out the data
										*		from the CP_Persistant class.
										*
										*	@param	inFile			The CP_File that we are writing to.
										*	@param	inWriter		The CP_PersistantWriter that is currently writing the
										*							persistant data.
										*
										*	\return	void
										*/
	virtual	void						WritePersistantData(
											CP_File& /*inFile*/,
											CP_PersistantWriter */*inWriter*/ )				{}
	//@}

protected:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Persistant();
	//@}

	//! @name FileType
	//@{
	virtual	void						GetFileTypeInfo(
												const CP_FileSystemSpec& inFileSpec,
												FourCharCode *inOutCreator,
												FourCharCode *inOutType,
												CP_String *inOutFileExtension );
	//@}

	// class data
protected:
	CP_FileSystemSpec					fFileSpec;
	
	bool								fDirty;
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Persistant

