//=========================================================================
//
//	FILE:				CP_PropertyList_Number.h
//	
//						Created by Jens Miltner on 01.12.04.
//	
//	PURPOSE:			CP_PropertyList numbers.
//	
//	HISTORY:			1st Version - January 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 115 $
//						Latest Checkout:  $Date: 2005-03-24 16:55:37 -0800 (Thu, 24 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_PropertyList_Number
#define _H_CP_PropertyList_Number

#include "CP_PropertyList_Node.h"
#if CP_PropertyList_Uses_CoreFoundation
#include "CP_CFMutableObject.h"
#endif

CPLAT_Begin_Namespace_CPLAT

namespace CP_PropertyList {

	class CP_EXPORT Number : public Node
#if CP_PropertyList_Uses_CoreFoundation
		,protected CP_CFObject<CFNumberRef>
#endif
	{
	public:
		enum NumberType_t
		{
			NumberType_Integer,
			NumberType_LargeInteger,
			NumberType_Float,
			NumberType_NaN
		};
		
		Number();
		explicit Number(UInt32 inValue);
		explicit Number(SInt32 inValue);
		explicit Number(UInt64 inValue);
		explicit Number(SInt64 inValue);
		explicit Number(double inValue);
		Number(const Number& inSrc);
	#if CP_PropertyList_Uses_CoreFoundation
		Number(CFNumberRef inRef, bool inRetain=true);
	#endif
		~Number() throw();
		
		NumberType_t NumberType() const throw();
		
		UInt32 GetUInt32() const;
		SInt32 GetSInt32() const;
		UInt32 GetUInt64() const;
		SInt32 GetSInt64() const;
		double GetFloat() const;
		
		virtual void PrintToLog(CP_LogFile& inLogFile, SInt32 inLevel=0, SInt32 inIndentLevel=0) const;
		virtual NodeType_t NodeType() const throw();
		
		static Number* FromXMLData(CP_InStream& inXMLDataStream);

	#if CP_PropertyList_Uses_CoreFoundation
		virtual CFTypeRef/*CFNumberRef*/ GetNodeCFRef() const;
	#endif
	#if !CP_PropertyList_Uses_CoreFoundation
	protected:
		//! write XML data for this node only (i.e. without xml header, plist root, etc.)
		virtual void WriteNodeXMLData(CP_OutStream& inXMLDataStream, int inLeadingSpaces) const;
	#endif
		
		// class data
	protected:
		#if !CP_PropertyList_Uses_CoreFoundation
			NumberType_t		fNumberType;
			
		enum InternalNumberType_t
		{
			Internal_NumberType_SInt32,   // stored number is an SInt32
			Internal_NumberType_UInt32,   // stored number is an UInt32
			Internal_NumberType_SInt64,   // stored number is an SInt64
			Internal_NumberType_UInt64,   // stored number is an UInt64
			Internal_NumberType_double,   // stored number is a double
			Internal_NumberType_NaN       // stored number is undefined
		};
		
		struct
		{
			InternalNumberType_t fType;
			union
			{
				SInt32  fSInt32;   // keep the SInt32 number
				UInt32  fUInt32;   // keep the UInt32 number
				SInt64  fSInt64;   // keep the SInt64 number
				UInt64  fUInt64;   // keep the UInt64 number
				double  fDouble;   // keep the double number
			} fData;
		} fNumber;           // our "real" number that keeps the data
			
		#endif // !CP_PropertyList_Uses_CoreFoundation
	};
	

} // end of namespace CP_PropertyList

CPLAT_End_Namespace_CPLAT

#endif // _H_CP_PropertyList_Number
