//=========================================================================
//
//	FILE:				CP_Document.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			DESCRIBE CLASS HERE
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Document
#define _H_CP_Document
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Document_Base.h"
#include "CP_EventHandler.h"
#include "CP_Printer.h"
#include "CP_ScriptableObject.h"

CPLAT_Begin_Namespace_CPLAT

template <class UNDO_POLICY, class PRINT_POLICY>
class CP_EXPORT CP_Document : public CP_Document_Base
{
public:
	typedef UNDO_POLICY					UndoPolicyType;
	typedef PRINT_POLICY				PrintPolicyType;

											// Construction / destruction
										CP_Document(
												CP_ScriptableObject *inContainer,
												SInt32 inDocType );
	virtual								~CP_Document() throw();

			PrintPolicyType& 			GetPrintPolicy()								{ return( fPrintPolicy ); }
			UndoPolicyType& 			GetUndoPolicy()									{ return( fUndoPolicy ); }
			
											// Commands
	virtual	void						HandlePageSetupUpdateCommandStatusCommand(
												CP_CommandStatus& inOutCommandStatus,
												bool& inOutWasHandled,
												CP_CommandNo& inCommandNo );
	virtual	void						HandlePageSetupCommand(
												OSStatus& inOutStatus,
												CP_CommandNo& inCommandNo );
	virtual	void						HandlePrintUpdateCommandStatusCommand(
												CP_CommandStatus& inOutCommandStatus,
												bool& inOutWasHandled,
												CP_CommandNo& inCommandNo );
	virtual	void						HandlePrintCommand(
												OSStatus& inOutStatus,
												CP_CommandNo& inCommandNo );
	virtual	void						HandleUndoCommandStatus(
												CP_CommandStatus& inOutCommandStatus,
												bool& inOutResult,
												CP_CommandNo& inCommand );
	virtual	void						HandleUndoCommand(
												OSStatus& inOutStatus,
												CP_CommandNo& inCommandNo );
	virtual	void						HandleRedoCommandStatus(
												CP_CommandStatus& inOutCommandStatus,
												bool& inOutResult,
												CP_CommandNo& inCommand );
	virtual	void						HandleRedoCommand(
												OSStatus& inOutStatus,
												CP_CommandNo& inCommand );
	
protected:
	virtual	void						HandleUndoEvent( CP_Event_Base& inEvent );

	//! @name Printing
	//@{
	virtual	void						HandlePrinting( CP_Printer */*inPrinter*/ )		{}
	//@}

private:

	// class data
protected:

private:
	CP_EventHandler						fEventHandler;	/*! CarbonEvent handler. */

	PRINT_POLICY						fPrintPolicy;
	UNDO_POLICY							fUndoPolicy;

	CP_PrintSignal						fPrintSignal;
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Document

