//=========================================================================
//
//	FILE:				CP_FileSystemSpec_Imp_Gtk.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Linux / Gtk implementation of the CP_FileSystemSpec_Imp class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_FileSystemSpec_Imp_Gtk
#define _H_CP_FileSystemSpec_Imp_Gtk
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_LINUX

	// CPLAT_Framework
#include "CP_String.h"

CPLAT_Begin_Namespace_CPLAT

class CP_EXPORT CP_FileSystemSpec_Imp
{
public:
											// Construction / destruction
	virtual								~CP_FileSystemSpec_Imp();
			
										/*!
										*	Return the name of this file system object as a CP_Stringn.
										*	
										*	@return	CP_String const		Nname of the file system object we point to.
										*/
			CP_String					GetName() const														{ return( fName ); }

											// Testers
										/*!
										*	Return true if this points to a valid file specification in the
										*	platforms native file system. The file can be valid, but not yet
										*	exist in the native file system.
										*	
										*	@return	bool const		True if the file specification is valid.
										*/
			bool						IsValid() const														{ return( fIsValid ); }

										/*!
										*	Return true if this points to a file that currently exists in the platforms
										*	native file system.
										*	
										*	@return	bool const		True if the file exists in the platforms native file system.
										*/
			bool						ExistsOnDisk() const												{ return( fExists ); }

			bool						IsEqual( const CP_FileSystemSpec_Imp& ) const;
			bool						IsDirectory() const;

protected:
											// Construction / destruction
										CP_FileSystemSpec_Imp();
										CP_FileSystemSpec_Imp( const CP_FileSystemSpec_Imp& inFileSpec_Imp );
										CP_FileSystemSpec_Imp( const CP_String& inFullPath );

										// operators
			CP_FileSystemSpec_Imp&		operator = ( const CP_FileSystemSpec_Imp& );

	// class data
protected:
	CP_String							fName;				/*! Name of the file */
	CP_String							fFullPath;			/*! Full path of the file */

	bool								fExists;			/*! flag to indicate if the file exists in the platforms file system */
	bool								fIsValid;			/*! flag to indicate if this object holds a valid specification for a file,
																which may or may not currently exist in the file system. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_LINUX

#endif	// _H_CP_FileSystemSpec_Imp_Gtk

