//=========================================================================
//
//	FILE:				CP_AE_ObjectDispatcher.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class to dispatch AppleEvents to the correct mix-in class
//						CP_ScriptableObject_Imp for handling in the classes method
//						DoAppleEvent.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 187 $
//						Latest Checkout:  $Date: 2005-05-22 13:06:02 -0700 (Sun, 22 May 2005) $
//
//=========================================================================
#ifndef _H_CP_AE_ObjectDispatcher
#define _H_CP_AE_ObjectDispatcher
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
//#include "AppleEvent.h"
#include "CP_ScriptableObject_Imp_AE.h"
#include "CP_SDEFParser.h"
	
CPLAT_Begin_Namespace_CPLAT

	// Errors returned by this object
//! CP_E_DispatchErrors
/*! Various errors this object will return. */
enum CP_E_DispatchErrors
{
	errAppleObjectDispatcherAlreadyInstalled = 1000,
	errAlreadyHaveAnApplication = 1001,
	errCantCopyTheApplication = 1002
};

/*!
*	@class		CP_AE_ObjectDispatcher
*	@brief		The AEDesc class is a MacOS only class to dispatch AppleEvents to the
*				correct mix-in class CP_ScriptableObject_Imp for handling in the classes method
*				DoAppleEvent.
*
*	@ingroup	AppleEvents
*/
class CP_EXPORT CP_AE_ObjectDispatcher
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_AE_ObjectDispatcher();
	//! Destructor.
	virtual								~CP_AE_ObjectDispatcher();
	//@}

	//! @name Instance
	//@{
	static	CP_AE_ObjectDispatcher		*Instance();
	//@}

	//! @name Initialization
	//@{
	virtual	void						Init();
	//@}
	
	//! @name Getters
	//@{
			SInt16						GetResolveFlags()								{ return( fAEResolveFlags ); }

		CP_SDEFParsing::CP_SDEFParser	*GetSDEFParser()								{ return( fSDEFParser ); }
	//@}

	//! @name Event Handlers
	//@{
	virtual	void						HandleAppleEventSelf(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply,
												SInt32 inRefCon );

	virtual	void						HandleCreateElement(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply );

	virtual	void						HandleCountElements(
												const AppleEvent& inEvent,
												AppleEvent& inOutReply );
	//@}

	//! @name Misc
	//@{
			OSErr						ResolveSpecifier(
												const AEDesc& inSpec,
												AEDesc& outToken );
	//@}

	//! @name OSL Handlers
	//@{
	virtual	void						HandleAccessContainedObjects(
												DescType inDesiredClass,
												const AEDesc& inContainer,
												DescType inContainerClass,
												DescType inKeyForm,
												const AEDesc& inKeyData,
												AEDesc& outToken );

	virtual	SInt32						HandleCountObjects(
												const AEDesc& inContainerToken,
												const DescType inCountObjectsOfType );

	virtual	bool						HandleCompareObjects(
												const DescType inOperation,
												const AEDesc& inObject1,
												const AEDesc& inObject2 );

	virtual	void						HandleDisposeToken( AEDesc& inToken );
	//@}
												
private:
	//! @name Registration
	//@{
			void						RegisterScriptingDefinitions();
	//@}

	//! @name Event Handlers
	//@{
	#if (UNIVERSAL_INTERFACES_VERSION >= 0x0337)
		static pascal	OSErr			AppleEventHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												SInt32 inRefCon );
		
		static pascal	OSErr			CreateElementHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												SInt32 inRefCon );

		static pascal	OSErr			CountObjectsHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												SInt32 inRefCon );
	#else
		static pascal	OSErr			AppleEventHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												UInt32 inRefCon );
		
		static pascal	OSErr			CreateElementHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												UInt32 inRefCon );

		static pascal	OSErr			CountObjectsHandler(
												const AppleEvent *inMessage,
												AppleEvent *inOutReply,
												UInt32 inRefCon );
	#endif
	//@}
	
	//! @name Events
	//@{
			void						ProcessEvent(
												const AppleEvent& inAppleEvent,
												AEDesc& inDirectObjToken,
												AEDesc& outResult,
												AppleEvent& outReply,
												SInt32 inRefCon );
	//@}

	//! @name OSL callbacks
	//@{
	static pascal	OSErr				OSLObjectAccessorHandler(
												const DescType inDesiredClass,
												const AEDesc *inContainer,
												const DescType inContainerClass,
												const DescType inForm,
												const AEDesc *inSelectionData,
												AEDesc *inValue,
												SInt32 inRefCon );

	static pascal	OSErr				OSLCountObjectsHandler(
												const DescType inCountObjectsOfType,
												const DescType inContainerClass,
												const AEDesc *inContainerToken,
												SInt32 *inResult );

	static pascal	OSErr				OSLCompareObjectsHandler(
												const DescType inOperation,
												const AEDesc *inObj1,
												const AEDesc *inObj2,
												Boolean *inOutResult );

	static pascal	OSErr				OSLDisposeTokenHandler( AEDesc *inToken );
	//@}

	//! @name Registration
	//@{
			void						RegisterCommands( CP_SDEFParsing::CP_SDEFParser *inSdefParser );
	//@}

	// class data members
private:
	static CP_AE_ObjectDispatcher		*fsInstance;		/* ! Single object dispatcher. */
	static bool							gInited;			/* ! Flag to indicate if handlers have been inited. */
	static OSErr						gErr;				/* ! Last dispatcher error. */

	CP_ScriptableObject_Imp				*fApplication;		/* ! Application object. */

	SInt16								fAEResolveFlags;

	CP_SDEFParsing::CP_SDEFParser		*fSDEFParser;
};

CPLAT_End_Namespace_CPLAT

#endif

#endif	// _H_CP_AE_ObjectDispatcher
