//=========================================================================
//
//	FILE:				CP_View_Imp_Control.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			MacOS implementation of a CP_View.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_View_Imp_Mac
#define _H_CP_View_Imp_Mac
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
#include "CP_Canvas.h"
#include "CP_Point.h"
#include "CP_Size.h"
#include "CP_View_Imp_Base.h"
#include "CP_Region.h"
#include "CP_View.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_View_Mac_Imp
*	@brief		MacOS implementation of the CP_View class.
*
*				Under MacOS non HIView all panes are implmented in this class as MacOS
*				user pane controls.
*/
class CP_EXPORT CP_View_Imp_Control : public CP_View_Imp_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_Control(
												CP_View_Imp *inOwnerViewImp,
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												bool inCreateImp = false );
	//! Destructor.
	virtual								~CP_View_Imp_Control() throw();
	//@}
			
	//! @name Appearance
	//@{
	virtual	void						Show();
	virtual	void						Hide();

	virtual	void						Activate();
	virtual	void						Deactivate();

	virtual	void						Enable();
	virtual	void						Disable();
	//@}
												
	//! @name Drawing
	//@{
	virtual	CP_Canvas					SetupForDrawing();
	virtual	void						HandleDraw( ControlRef inControl );

	virtual	void						Draw();
	virtual	void						PrepareDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	virtual	void						Refresh();
	//@}

	//! @name Events
	//@{
	virtual	ControlPartCode				HandleHitTest(
												ControlRef inControl,
												const CP_Point& inMouseLocation );
	virtual	ControlPartCode				HandleTracking(
												ControlRef inControl,
												const CP_Point& inMouseLocation,
												ControlActionUPP inActionProc );
	virtual	ControlPartCode				HandleFocus(
												ControlRef inControl,
												ControlFocusPart inAction );
	virtual	void						HandleIdle( ControlRef inControl );
	virtual	void						HandleActivate(
												ControlRef inControl,
												Boolean inActivating );
	virtual	void						HandleKeyDown(
												ControlRef inControl,
												SInt16 keyCode,
												SInt16 charCode,
												SInt16 modifiers );
	//@}

	//! @name Getters
	//@{
	virtual	CP_EventHandler&			GetEventHandler();
	virtual	CP_Rect						GetPortBounds();
	//@}

	//! @name Positioning
	//@{
	virtual	void						Move( const CP_Point& inOffset );
	//@}

	//! @name Superview
	//@{
	virtual	void						AddSubview( CP_View_Imp *inView );
	virtual	void						AdjustToSuperview( CP_View *inView );
	//@}

	//! @name Positioning
	//@{
	virtual	void						SetPortBounds( const CP_Rect& inBounds );
	virtual	void						SetLocation( const CP_Point& inLocation );
	virtual	void						SetSize( const CP_Size& inSize );
	//@}

	//! @name Testers
	//@{
	virtual	bool						IsVisible() const;
	virtual	bool						IsActive() const;
	virtual	bool						IsEnabled() const;
	//@}

protected:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_View_Imp_Control();
	//@}

	//! @name Drawing
	//@{
			void						Invalidate( const CP_Region& inInvalidArea );
	virtual	void						HandleDrawInCanvas(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreateUserPaneControl(
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//@}

	// class data
protected:
		// static UserPane UPPs
	static ControlUserPaneDrawUPP		fsPaneImp_DrawProc;				/*! ControlManager callback to draw the contents of this pane.  */
	static ControlUserPaneHitTestUPP	fsPaneImp_HitTestProc;			/*! ControlManager callback for hit testing of this pane.  */
	static ControlUserPaneTrackingUPP	fsPaneImp_PaneTrackingProc;		/*! ControlManager callback for tracking of this pane.  */
	static ControlUserPaneFocusUPP		fsPaneImp_PaneFocusProc;		/*! ControlManager callback for tracking of this pane.  */
	static ControlUserPaneIdleUPP		fsPaneImp_PaneIdleProc;			/*! ControlManager callback for idle time in this pane.  */
	static ControlUserPaneActivateUPP	fsPaneImp_PaneActivateProc;		/*! ControlManager callback for pane activate in this pane.  */
	static ControlUserPaneKeyDownUPP	fsPaneImp_PaneKeyDownProc;		/*! ControlManager callback for keydowns in this pane.  */

	CP_EventHandler						fEventHandler;					/*! Event handler to handle events for this control.  */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_MAC

#endif	// _H_CP_View_Imp_Mac

