//=========================================================================
//
//	FILE:				CP_RoundButton.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms round button control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_RoundButton
#define _H_CP_RoundButton
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"
#include "CP_Structure_Defines.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_RoundButton
*	@brief		Implementation of a platforms round button control.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_RoundButton : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_RoundButton();
								CP_RoundButton(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										const CP_S_ViewContentInfo& inContentInfo,
										UInt32 inCommand,
										SInt16 inButtonSize = 0 );
	//! Destructor.
	virtual						~CP_RoundButton() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist			*PersistCreator();
	//@}
			
protected:
	//! @name Persistance
	//@{
	virtual	void				OnInitPersist(
										CP_View *inSuperview,
										CP_DataValueList& inDataValueList );
	//@}


	// class data
protected:
	CP_S_ViewContentInfo		fContentInfo;	/*! Structure used to hold information about
															the contents of the button. */
	
	bool						fIsPushed;

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Slots
	//@{
	virtual	void				HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										UInt32 inCommand,
										SInt16 inButtonSize );
	//@}

	//! @name Drawing
	//@{
			CP_RGBColor			GetColor(
										double dAngle,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crColour,
										bool bDashed );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
	//@}

	//! @name Events
	//@{
			void				HandleMouseDown( CP_Event_Base& inEvent );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name Slots
	//@{
	virtual	void				HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Events
	//@{
			void				HandleMouseDown( CP_Event_Base& inEvent );
	//@}

	//! @name Drawing
	//@{
			CP_RGBColor			GetColor(
										double dAngle,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crColour,
										bool bDashed );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
	//@}

	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										UInt32 inCommand,
										SInt16 inButtonSize );
	//@}
#endif

#if TARGET_OS_LINUX
public:
	//! @name Slots
	//@{
	virtual	void				HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

	//! @name Events
	//@{
	virtual	void				HandleMouseDown( CP_Event_Base& inEvent );
	virtual	void				HandleMouseUp( CP_Event_Base& inEvent );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void				OnDraw(
										CP_Canvas& inCanvas,
										CP_Region& inUpdateArea );
	//@}

private:
	//! @name Drawing
	//@{
			CP_RGBColor			GetColor(
										double dAngle,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crColour,
										bool bDashed );
			void				DrawCircle(
										CP_Canvas& inCanvas,
										CP_Point p,
										SInt32 lRadius,
										CP_RGBColor& crBright,
										CP_RGBColor& crDark );
	//@}

	//! @name Initialization
	//@{
			void				CreatePlatformImp(
										CP_View *inSuperview,
										const CP_Point& inUpperLeft,
										const CP_Size& inContentSize,
										UInt32 inCommand,
										SInt16 inButtonSize );
	//@}
#endif

};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_RoundButton
