//=========================================================================
//
//	FILE:				CP_TV_DataBrowserHandlers.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			DESCRIBE CLASS HERE
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 160 $
//						Latest Checkout:  $Date: 2005-04-27 21:21:26 -0700 (Wed, 27 Apr 2005) $
//
//=========================================================================
#ifndef _H_CP_TV_DataBrowserHandlers
#define _H_CP_TV_DataBrowserHandlers
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_ARGBColor.h"
#include "CP_DataValueList.h"
#include "CP_InPlaceEditField.h"
#include "CP_M_ReferenceCounted.h"
#include "CP_OSIcon.h"
#include "CP_TV_DataBrowser_Defines.h"


#include "CP_SignalSlot.h"

CPLAT_Begin_Namespace_CPLAT

//=========================================================================
//	Content handler data values
//=========================================================================
#define kCP_ContentHandler_HorAlign								"hor_align"
#define kCP_ContentHandler_VerAlign								"ver_align"
#define kCP_ContentHandler_FontSpec								"font_spec"

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_Base ==
#endif

/*!
*	\class		CP_TV_DataBrowser_CH_Base
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_Base : public CP_M_RefCounted, public CP_SigSlot::CP_SlotObject, public CP_Object
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_Base() throw();
	//@}

	//! @name Drawing
	//@{
			void						Draw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}
			
	//! @name Events
	//@{
	virtual bool						HandlesClicks()									{ return( false ); }
	virtual	void						HandleClick(
												CP_S_TV_DB_ParamBlock& /*inParamBlock*/,
												const CP_Point& /*inMouseLocation*/ )	{}
	//@}

	//! @name Properties
	//@{
			void						AddProperty(
												const CP_String& inDataKey,
												const CP_DataValueHolder& inDataValue );			
			void						SetProperty(
												const CP_String& inDataKey,
												const CP_DataValueHolder& inDataValue );			

			bool						GetOptionalProperty(
												const CP_String& inDataKey,
												CP_DataValueHolder& inOutDataValue );
	//@}

	virtual	void						HandleRowExpanded( CP_S_TV_DB_ParamBlock& inParamBlock );
	virtual	void						HandleRowCollapsed( CP_S_TV_DB_ParamBlock& inParamBlock );

protected:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_Base();
	//@}

	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

	// class data
protected:
	SInt16						fLeftIndent;			// user indent for left side to data
	SInt16						fTopIndent;				// user indent for top side to data
	SInt16						fRightIndent;			// user indent for right side to data
	SInt16						fBottomIndent;			// user indent for bottom side to data
	bool						fEditingSupported;		// can we edit the values in the cell
	CP_DataValueList			fHandlerProperties;
};

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_Background ==
#endif

/*!
*	\class		CP_TV_DataBrowser_CH_Background
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_Background : public CP_TV_DataBrowser_CH_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_Background();
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_Background() throw();
	//@}

	virtual	void						SetupCanvas(
												CP_Canvas& /*inDestCanvas*/,
												CP_S_TV_DB_ParamBlock& /*inParamBlock*/ )				{}
	
	//! @name Getters
	//@{
			CP_ARGBColor				GetBackgroundColor()											{ return( fBackgroundColor ); }
			CP_ARGBColor				GetSelectedColBackgroundColor()									{ return( fSelectedColumnBackgroundColor ); }
	//@}

	//! @name Setters
	//@{
			void						SetBackgroundColor( const CP_ARGBColor& inColor )				{ fBackgroundColor = inColor; }
			void						SetSelectedColBackgroundColor( const CP_ARGBColor& inColor )	{ fSelectedColumnBackgroundColor = inColor; }
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

	// class data
protected:
	CP_ARGBColor						fBackgroundColor;
	CP_ARGBColor						fSelectedColumnBackgroundColor;
};

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_IconAndText ==
#endif

struct CP_S_CH_IconTextItemInfo
{
	CP_OSIcon			fOSIcon;
	CP_String			fText;

								CP_S_CH_IconTextItemInfo();
								CP_S_CH_IconTextItemInfo(
										CP_OSIcon& inIcon,
										const CP_String& inText );
								CP_S_CH_IconTextItemInfo( const CP_S_CH_IconTextItemInfo& inItemInfo );

	CP_S_CH_IconTextItemInfo&	operator =( const CP_S_CH_IconTextItemInfo& inItemInfo );
};

/*!
*	\class		CP_TV_DataBrowser_CH_IconAndText
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_IconAndText : public CP_TV_DataBrowser_CH_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_IconAndText();
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_IconAndText() throw();
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

private:
			CP_Rect						GetIconBounds(
												const CP_Rect& inCellBounds,
												CP_OSIcon& inIcon ) const;
			CP_Rect						GetTextBounds(
												const CP_Rect& inCellBounds,
												const CP_Rect& inIconBounds ) const;

	// class data
protected:
};

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_String ==
#endif

/*!
*	\class		CP_TV_DataBrowser_CH_String
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_String : public CP_TV_DataBrowser_CH_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_String();
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_String() throw();
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

	// class data
protected:
};

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_EditString ==
#endif

/*!
*	\class		CP_TV_DataBrowser_CH_EditString
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_EditString : public CP_TV_DataBrowser_CH_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_EditString();
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_EditString() throw();
	//@}

	//! @name Events
	//@{
	virtual bool						HandlesClicks()									{ return( true ); }
	virtual	void						HandleClick(
												CP_S_TV_DB_ParamBlock& inParamBlock,
												const CP_Point& inMouseLocation );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

	virtual	void						EndEdit();

private:
			void						TextFieldExit(
												CP_DataValueHolder& inDataValue,
												OSStatus& inOutStatus );

	// class data
protected:
	CP_S_TV_DB_ParamBlock				fParamBlock;

	CP_InPlaceEditField					*fInPlaceEditField;
};

#if TARGET_CC_METROWERKS
#pragma mark === CP_TV_DataBrowser_CH_View ==
#endif

/*!
*	\class		CP_TV_DataBrowser_CH_View
*	\brief		Base content handler.
*/
class CP_EXPORT CP_TV_DataBrowser_CH_View : public CP_TV_DataBrowser_CH_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_TV_DataBrowser_CH_View();
	//! Destructor.
	virtual								~CP_TV_DataBrowser_CH_View() throw();
	//@}

	virtual	void						HandleRowCollapsed( CP_S_TV_DB_ParamBlock& inParamBlock );

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inDestCanvas,
												CP_S_TV_DB_ParamBlock& inParamBlock );
	//@}

			void						CreateView( CP_S_TV_DB_ParamBlock& inParamBlock );

private:

	// class data
protected:
	CP_S_TV_DB_ParamBlock				fParamBlock;

		// Signals
	CP_DataValueSignal					fHelperViewCreatedSignal;	/*! Signal sent when the helper view is created. */
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_TV_DataBrowserHandlers

